@@ -5,7 +5,7 @@ use Data::Printer::Object;
 use Data::Printer::Common;
 use Data::Printer::Config;
 
-our $VERSION = '0.99_014';
+our $VERSION = '0.99_015';
 
 my $rc_arguments;
 my %arguments_for;
@@ -163,22 +163,22 @@ sub _fetch_args_with {
 
     my $args_to_use = {};
     if (keys %$rc_arguments) {
-        $args_to_use = Data::Printer::Common::merge_options(
+        $args_to_use = Data::Printer::Common::_merge_options(
             $args_to_use, $rc_arguments->{'_'}
         );
         if (exists $rc_arguments->{$caller}) {
-            $args_to_use = Data::Printer::Common::merge_options(
+            $args_to_use = Data::Printer::Common::_merge_options(
                 $args_to_use, $rc_arguments->{$caller}
             );
         }
     }
     if ($arguments_for{$caller}) {
-        $args_to_use = Data::Printer::Common::merge_options(
+        $args_to_use = Data::Printer::Common::_merge_options(
             $args_to_use, $arguments_for{$caller}
         );
     }
     if (keys %$run_properties) {
-        $args_to_use = Data::Printer::Common::merge_options(
+        $args_to_use = Data::Printer::Common::_merge_options(
             $args_to_use, $run_properties
         );
     }
@@ -201,7 +201,7 @@ Want to see what's inside a variable in a complete, colored and human-friendly w
     use DDP; p $var;
     use DDP; p $var, as => "This label will be printed too!";
 
-    # no need to use '\' before arrays or hashes
+    # no need to use '\' before arrays or hashes!
     p @array;
     p %hash;
 
@@ -530,6 +530,24 @@ array index you had originally.
 
 =head2 Colors & Themes
 
+Data::Printer's colorization is set via the C<colorize> output, which can be
+set to C<1> (always colorize), C<0> (never colorize) or C<'auto'>.
+
+Data::Printer's default color mode is 'auto', meaning it will colorize
+the output only when all conditions below are met:
+
+=over 4
+
+=item * There is no C<ANSI_COLORS_DISABLED> environment variable;
+
+=item * The output is going to the terminal, not just returned;
+
+=item * The output handle (STDERR by default) is not being piped;
+
+=item * Your terminal supports colors (most do nowadays).
+
+=back
+
 Data::Printer's colored output is handled by the C<colors> option. You may
 set each color individually, using ANSIColors naming, hex color tags or RGB:
 
